@@ -65,7 +65,7 @@ dark_mode_r <- function (
     base_family = "",
     base_colour = "#C8D7DFFF",
     axis_line_colour = "#C8D7DFFF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     panel_grid_colour = "#00040AFF",
@@ -73,7 +73,7 @@ dark_mode_r <- function (
     panel_background_fill ="#050D1BFF",
     plot_background_fill = "#00040AFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
@@ -115,7 +115,7 @@ dark_mode_t <- function (
     base_family = "",
     base_colour = "#C8D7DFFF",
     axis_line_colour = "#C8D7DFFF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     panel_grid_colour = "#00040AFF",
@@ -123,7 +123,7 @@ dark_mode_t <- function (
     panel_background_fill ="#050D1BFF",
     plot_background_fill = "#00040AFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
@@ -165,7 +165,7 @@ dark_mode_b <- function (
     base_family = "",
     base_colour = "#C8D7DFFF",
     axis_line_colour = "#C8D7DFFF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     panel_grid_colour = "#00040AFF",
@@ -173,7 +173,7 @@ dark_mode_b <- function (
     panel_background_fill ="#050D1BFF",
     plot_background_fill = "#00040AFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
