@@ -58,7 +58,7 @@ flex_mode_base <- function(
     plot_caption_face = "plain",
     plot_caption_hjust = 0,
     axis_line_colour = "#121B24FF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     axis.ticks.length = grid::unit(base_size / 3, "pt"),
@@ -68,7 +68,7 @@ flex_mode_base <- function(
     panel_background_fill ="#FFFFFFFF",
     plot_background_fill = "#FFFFFFFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
@@ -216,7 +216,7 @@ flex_mode_r <- function (
     plot_caption_colour = colorspace::lighten(base_colour, 0.1),
     plot_caption_hjust = 0,
     axis_line_colour = "#121B24FF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     axis.ticks.length = grid::unit(base_size / 3, "pt"),
@@ -226,7 +226,7 @@ flex_mode_r <- function (
     panel_background_fill ="#FFFFFFFF",
     plot_background_fill = "#FFFFFFFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
@@ -304,7 +304,7 @@ flex_mode_t <- function (
     plot_caption_colour = colorspace::lighten(base_colour, 0.1),
     plot_caption_hjust = 0,
     axis_line_colour = "#121B24FF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     axis.ticks.length = grid::unit(base_size / 3, "pt"),
@@ -314,7 +314,7 @@ flex_mode_t <- function (
     panel_background_fill ="#FFFFFFFF",
     plot_background_fill = "#FFFFFFFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
@@ -407,7 +407,7 @@ flex_mode_b <- function (
     plot_caption_colour = colorspace::lighten(base_colour, 0.1),
     plot_caption_hjust = 0,
     axis_line_colour = "#121B24FF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     axis.ticks.length = grid::unit(base_size / 3, "pt"),
@@ -417,7 +417,7 @@ flex_mode_b <- function (
     panel_background_fill ="#FFFFFFFF",
     plot_background_fill = "#FFFFFFFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
