@@ -27,7 +27,7 @@ gg_density_2d <- function(data = NULL,
                           stat = "density_2d",
                           position = "identity",
                           coord = ggplot2::coord_cartesian(clip = "off"),
-                          mode = NULL, mode_orientation = NULL,
+                          mode = NULL, mode_orientation = NULL, blend = NULL,
                           x = NULL,
                           xmin = NULL,
                           xmax = NULL,
@@ -98,7 +98,7 @@ gg_density_2d <- function(data = NULL,
     stat = stat,
     position = position,
     coord = coord,
-    mode = mode, mode_orientation = mode_orientation,
+    mode = mode, mode_orientation = mode_orientation, blend = blend,
     x = {{ x }},
     y = {{ y }},
     xmin = {{ xmin }},
