@@ -36,7 +36,7 @@ gg_errorbar <- function(data = NULL,
                         stat = "identity",
                         position = "identity",
                         coord = ggplot2::coord_cartesian(clip = "off"),
-                        mode = NULL, mode_orientation = NULL,
+                        mode = NULL, mode_orientation = NULL, blend = NULL,
                         x = NULL,
                         xmin = NULL,
                         xmax = NULL,
@@ -107,7 +107,7 @@ gg_errorbar <- function(data = NULL,
     stat = stat,
     position = position,
     coord = coord,
-    mode = mode, mode_orientation = mode_orientation,
+    mode = mode, mode_orientation = mode_orientation, blend = blend,
     x = {{ x }},
     y = {{ y }},
     xmin = {{ xmin }},
