@@ -31,7 +31,7 @@ gg_jitter <- function(data = NULL,
                       stat = "identity",
                       position = "jitter",
                       coord = ggplot2::coord_cartesian(clip = "off"),
-                      mode = NULL, mode_orientation = NULL,
+                      mode = NULL, mode_orientation = NULL, blend = NULL,
                       x = NULL,
                       xmin = NULL,
                       xmax = NULL,
@@ -102,7 +102,7 @@ gg_jitter <- function(data = NULL,
     stat = stat,
     position = position,
     coord = coord,
-    mode = mode, mode_orientation = mode_orientation,
+    mode = mode, mode_orientation = mode_orientation, blend = blend,
     x = {{ x }},
     y = {{ y }},
     xmin = {{ xmin }},
