@@ -47,7 +47,7 @@ gg_polygon <- function(data = NULL,
                        stat = "identity",
                        position = "identity",
                        coord = ggplot2::coord_cartesian(clip = "off"),
-                       mode = NULL, mode_orientation = NULL,
+                       mode = NULL, mode_orientation = NULL, blend = NULL,
                        x = NULL,
                        xmin = NULL,
                        xmax = NULL,
@@ -118,7 +118,7 @@ gg_polygon <- function(data = NULL,
     stat = stat,
     position = position,
     coord = coord,
-    mode = mode, mode_orientation = mode_orientation,
+    mode = mode, mode_orientation = mode_orientation, blend = blend,
     x = {{ x }},
     y = {{ y }},
     xmin = {{ xmin }},
