@@ -25,7 +25,7 @@ gg_sf <- function(data = NULL,
                   stat = "sf",
                   position = "identity",
                   coord = ggplot2::coord_sf(clip = "off"),
-                  mode = NULL, mode_orientation = NULL,
+                  mode = NULL, mode_orientation = NULL, blend = NULL,
                   x = NULL,
                   xmin = NULL,
                   xmax = NULL,
@@ -96,7 +96,7 @@ gg_sf <- function(data = NULL,
     stat = stat,
     position = position,
     coord = coord,
-    mode = mode, mode_orientation = mode_orientation,
+    mode = mode, mode_orientation = mode_orientation, blend = blend,
     x = {{ x }},
     y = {{ y }},
     xmin = {{ xmin }},
