@@ -21,7 +21,6 @@
 #'   gg_text(
 #'     x = model,
 #'     y = mpg,
-#'     col = mpg,
 #'     label = model,
 #'     y_expand_limits = 0,
 #'     y_label = "Miles per gallon",
@@ -33,7 +32,7 @@ gg_text <- function(data = NULL,
                     stat = "identity",
                     position = "identity",
                     coord = ggplot2::coord_cartesian(clip = "off"),
-                    mode = NULL, mode_orientation = NULL,
+                    mode = NULL, mode_orientation = NULL, blend = NULL,
                     x = NULL,
                     xmin = NULL,
                     xmax = NULL,
@@ -52,14 +51,14 @@ gg_text <- function(data = NULL,
                     text = NULL,
                     sample = NULL,
                     mapping = NULL,
-                    x_breaks = NULL, x_breaks_n = NULL, 
+                    x_breaks = NULL, x_breaks_n = NULL,
                     x_expand = NULL,
                     x_expand_limits = NULL,
-                    x_label = NULL, x_labels = NULL, 
-                    
-                    
-                    x_position = "bottom", 
-                    
+                    x_label = NULL, x_labels = NULL,
+
+
+                    x_position = "bottom",
+
                     x_sec_axis = ggplot2::waiver(), x_symmetric = NULL, x_transform = NULL,
                     y_breaks = NULL, y_breaks_n = NULL,
                     y_expand = NULL,
@@ -67,8 +66,8 @@ gg_text <- function(data = NULL,
                     y_label = NULL, y_labels = NULL,
                      y_position = "left",
                     y_sec_axis = ggplot2::waiver(),
-                    y_symmetric = NULL, 
-                    
+                    y_symmetric = NULL,
+
                     y_transform = NULL,
                     col_breaks = NULL, col_breaks_n = 5,
                     col_drop = FALSE,
@@ -77,13 +76,13 @@ gg_text <- function(data = NULL,
                     col_legend_ncol = NULL,
                     col_legend_nrow = NULL,
                     col_legend_rev = FALSE,
-                    
-                    
+
+
                     col_palette = NULL,
                     col_palette_na = NULL,
                     col_rescale = scales::rescale(),
                     col_steps = FALSE,
-                    
+
                     col_transform = NULL,
                     facet_axes = NULL,
                     facet_axis_labels = "margins",
@@ -104,7 +103,7 @@ gg_text <- function(data = NULL,
     stat = stat,
     position = position,
     coord = coord,
-    mode = mode, mode_orientation = mode_orientation,
+    mode = mode, mode_orientation = mode_orientation, blend = blend,
     x = {{ x }},
     y = {{ y }},
     xmin = {{ xmin }},
@@ -149,7 +148,7 @@ gg_text <- function(data = NULL,
     col_legend_nrow = col_legend_nrow,
     col_legend_rev = col_legend_rev,
     col_breaks_n = col_breaks_n,
-    
+
     col_palette = col_palette,
     col_palette_na = col_palette_na,
     col_rescale = col_rescale,
