@@ -65,7 +65,7 @@ light_mode_r <- function (
     base_family = "",
     base_colour = "#121B24FF",
     axis_line_colour = "#121B24FF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     panel_grid_colour = "#F6F8FAFF",
@@ -73,7 +73,7 @@ light_mode_r <- function (
     panel_background_fill ="#FFFFFFFF",
     plot_background_fill = "#FFFFFFFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
@@ -112,7 +112,7 @@ light_mode_t <- function (
     base_family = "",
     base_colour = "#121B24FF",
     axis_line_colour = "#121B24FF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     panel_grid_colour = "#F6F8FAFF",
@@ -120,7 +120,7 @@ light_mode_t <- function (
     panel_background_fill ="#FFFFFFFF",
     plot_background_fill = "#FFFFFFFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
@@ -157,7 +157,7 @@ light_mode_b <- function (
     base_family = "",
     base_colour = "#121B24FF",
     axis_line_colour = "#121B24FF",
-    axis_line_linewidth = 0.33,
+    axis_line_linewidth = 0.25,
     axis_ticks_colour = axis_line_colour,
     axis_ticks_linewidth = axis_line_linewidth,
     panel_grid_colour = "#F6F8FAFF",
@@ -165,7 +165,7 @@ light_mode_b <- function (
     panel_background_fill ="#FFFFFFFF",
     plot_background_fill = "#FFFFFFFF",
     legend_axis_line_colour = plot_background_fill,
-    legend_axis_line_linewidth = 0.33,
+    legend_axis_line_linewidth = axis_line_linewidth,
     legend_background_fill = plot_background_fill,
     legend_key_fill = plot_background_fill,
     legend_ticks_colour = legend_axis_line_colour,
