@@ -1,7 +1,7 @@
 #' Mode colour and linewidth defaults
 #'
 #' @description
-#' `lightness`, `greyness` and `darkness` are vectors of 3 colours used in the `*_mode_*` themes for the for the text, axis.line (and axis.ticks), panel.grid, panel.background and plot.background etc.
+#' `lightness` and `darkness` are vectors of 3 colours used in the `*_mode_*` themes for the for the text, axis.line (and axis.ticks), panel.grid, panel.background and plot.background etc.
 #'
 #' `linewidthness` is a vector of 2 integers used in the `*_mode_*` themes for the linewidth of the axis.line (axis.ticks and legend.ticks) and panel.grid theme elements.
 #'
@@ -10,14 +10,9 @@
 #' @export
 #'
 #' @examples
-#' scales::show_col(c(lightness, greyness, darkness), ncol = 3)
+#' scales::show_col(c(lightness, darkness), ncol = 3)
 lightness <- c("#121B24FF", "#F6F8FAFF", "#FFFFFFFF")
 
-#' @rdname lightness
-#' @format NULL
-#' @export
-greyness <- c("#121B24FF", "#F6F8FAFF", "#FCFDFEFF")
-
 #' @rdname lightness
 #' @format NULL
 #' @export
