@@ -298,12 +298,11 @@ test_that(test_name, {
     gg_label(
       x = model,
       y = mpg,
-      col = mpg,
       label = model,
       size = 3.53,
       y_expand_limits = 0,
       y_label = "Miles per gallon",
-      col_palette = c(orange, "white", teal),
+      # col_palette = c(orange, "white", teal),
     )
 
   vdiffr::expect_doppelganger(test_name, p)
@@ -612,7 +611,6 @@ test_that(test_name, {
     gg_text(
       x = model,
       y = mpg,
-      col = mpg,
       label = model,
       size = 3.53,
       y_expand_limits = 0,
