@@ -98,43 +98,3 @@ test_that(test_name, {
 
     vdiffr::expect_doppelganger(test_name, p)
 })
-
-test_name <- "transform_log10"
-
-test_that(test_name, {
-  p <- penguins |>
-    drop_na(sex) |>
-    mutate(across(sex, \(x) str_to_sentence(x))) |>
-    gg_blanket(
-      geom = GeomViolin,
-      stat = StatYdensity,
-      position = PositionDodge,
-      y_transform = scales::transform_log10(),
-      x = sex,
-      y = body_mass_g,
-      col = species,
-    )
-
-    vdiffr::expect_doppelganger(test_name, p)
-})
-
-test_name <- "transform_reverse"
-
-test_that(test_name, {
-  p <- penguins |>
-    drop_na(sex) |>
-    mutate(across(sex, \(x) str_to_sentence(x))) |>
-    gg_blanket(
-      geom = GeomViolin,
-      stat = StatYdensity,
-      position = PositionDodge,
-      y_transform = scales::transform_reverse(),
-      x = sex,
-      y = body_mass_g,
-      col = species,
-    )
-
-    vdiffr::expect_doppelganger(test_name, p)
-})
-
-set_blanket()
